辛德勒的名单 (豆瓣)
Description: 辛德勒的名单电影简介和剧情介绍,辛德勒的名单影评、图片、预告片、影讯、论坛、在线购票
Keywords: 辛德勒的名单,Schindler's List,辛德勒的名单影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.8豆瓣电影Top250

# 辛德勒的名单 Schindler's List (1993)

更新描述或海报

导演: 史蒂文·斯皮尔伯格
编剧: 托马斯·肯尼利 / 斯蒂文·泽里安
主演: 连姆·尼森 / 本·金斯利 / 拉尔夫·费因斯 / 卡罗琳·古多尔 / 乔纳森·萨加尔 / 艾伯丝·戴维兹 / 马尔戈萨·格贝尔 / 马克·伊瓦涅 / 碧翠斯·马科拉 / 安德烈·瑟韦林 / 弗里德里希·冯·图恩 / 克齐斯茨托夫·拉夫特 / 诺伯特·魏塞尔 / 维斯瓦夫·科马萨
类型: 剧情 / 历史 / 战争
制片国家/地区: 美国
语言: 英语 / 希伯来语 / 德语 / 波兰语
上映日期: 1993-11-30(华盛顿首映) / 1994-02-04(美国)
片长: 195分钟
又名: 舒特拉的名单(港) / 辛德勒名单
IMDb: tt0108052
豆瓣评分
引用
9.6
1053086人评价
5星
80.3%
4星
17.5%
3星
2.0%
2星
0.1%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
10.0
3人评价
好于 99% 战争片
好于 99% 历史片
想看 看过
评价:
推荐

## 辛德勒的名单的剧情简介 · · · · · ·

1939年，波兰在纳粹德国的统治下，党卫军对犹太人进行了隔离统治。德国商人奥斯卡·辛德勒（连姆·尼森 Liam Neeson 饰）来到德军统治下的克拉科夫，开设了一间搪瓷厂，生产军需用品。凭着出众的社交能力和大量的金钱，辛德勒和德军建立了良好的关系，他的工厂雇用犹太人工作，大发战争财。
1943年，克拉科夫的犹太人遭到了惨绝人寰的大屠杀，辛德勒目睹这一切，受到了极大的震撼，他贿赂军官，让自己的工厂成为集中营的附属劳役营，在那些疯狂屠杀的日子里，他的工厂也成为了犹太人的避难所。
1944年，德国战败前夕，屠杀犹太人的行动越发疯狂，辛德勒向德军军官开出了1200人的名单，倾家荡产买下了这些犹太人的生命。在那些暗无天日的岁月里，拯救一个人，就是拯救全世界。 ©豆瓣

## 辛德勒的名单的演职员 · · · · · · ( 全部 70 )

- 史蒂文·斯皮尔伯格 导演
- 连姆·尼森 饰 Oskar Schindler
- 本·金斯利 饰 Itzhak Stern
- 拉尔夫·费因斯 饰 Amon Goeth
- 卡罗琳·古多尔 饰 Emilie Schindler
- 乔纳森·萨加尔 饰 Poldek Pfefferberg

## 辛德勒的名单的视频和图片 · · · · · · ( 预告片4 | 视频评论2 · 添加 | 图片1030 · 添加 )

## 辛德勒的名单的获奖情况 · · · · · · ( 全部 )

- 第66届奥斯卡金像奖
- 最佳影片
- 杰拉尔德·R·莫伦 / 布兰科·拉斯蒂格 / 史蒂文·斯皮尔伯格

- 第51届金球奖
- 电影类 最佳剧情片

- 第47届英国电影学院奖
- 电影奖 最佳影片
- 史蒂文·斯皮尔伯格 / 杰拉尔德·R·莫伦 / 布兰科·拉斯蒂格

## 喜欢这部电影的人也喜欢 · · · · · ·

  拯救大兵瑞恩

  穿条纹睡衣的男孩

  钢琴家

  血战钢锯岭

  1917

  敦刻尔克

  美丽人生

  黑鹰坠落

  兵临城下

  卢旺达饭店

我要写短评

## 辛德勒的名单的短评 · · · · · · ( 全部 175763 条 )

热门 / 最新 / 好友

### 11417 有用 宝塔糖 看过 2011-07-09 02:37:35

有钱才能保护喜欢的人

### 3418 有用 文泽尔 看过 2007-10-12 07:32:32

这不止是剧情，更是技术、镜头、剪辑、演技和配乐的综合胜利。表达是一出技巧活，不以剧本和背景定优劣，这一切都是导演的功力和运气造成，不可求，但可遇——《辛德勒的名单》可谓厚积薄发。而实论背景，辛德勒本人之事尚存争议，电影却已在全世界人面前诠释并且定性了，由此可见媒体的影响之大

### 4009 有用 西梨 看过 2008-06-29 23:14:08

出门的时候，看到灯火辉煌的城市，会觉得一切幸福美好都是罪恶。。。

### 7211 有用 2013 看过 2006-09-11 17:44:34

印象很深刻的是黑白画面中的红色。

### 2854 有用 LORENZO 洛伦佐 看过 2012-01-04 03:27:10

最后辛德勒摘下自己的胸针，说自己原本还能再救一个人，痛哭失声的时候，我也已经哭得不成人形。从电影的任何一个角度都达到了直击人心的力量，面对人性，面对生命，辛德勒做出了让历史铭记的选择。经典之至，感人至深。

> 更多短评 175763条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 LLudeer 看过 2020-03-21 22:54:52

小学的某个课堂里看过片段，但细节完全记不清了，就记得是黑白的。三个多小时，全程处在极度压抑的状态下，当那群女生被要求全部脱光进入房间，所有的灯全部关掉的一瞬间，我的心也咯噔了一下。是人生中必看的一部电影。

### 0 有用 猴子 看过 2014-02-09 21:45:42

太伟大，看哭了

我要写影评

## 辛德勒的名单的影评 · · · · · · ( 全部 2964 条 )

热门 / 最新 / 好友
cxyboy 2006-04-21 22:21:24

## 重观《辛德勒名单》中80个难忘的经典影像片段（部分转载）

这篇影评可能有剧透

世界反法西斯胜利60周年 　　1945-2005 　　 　　NO.00-【即将来临的黑夜】 　　一个普通的犹太人家庭在低声吟唱着圣咏曲，微弱的烛光渐渐熄灭，一缕白烟缓缓升起，慢慢变成火车轰鸣的烟雾…影片字幕：1939年9月，德国武装在两个星期内击败了波兰军队。下令犹太人登记全家人口... (展开)
6555 168 466回应 收起
农民老郑🌈 2009-08-09 21:56:24

## 辛德勒先生，我也想在你的墓碑上放上一块石头。

对这部磅礴伟大的电影，实在不敢妄加评论。可是，又觉得对于这样一直想看却一直不敢看的电影，如果不写点什么，也实在难以告慰自己粗鄙又真挚的感情。 哎，好生纠结。一如辛德勒先生的每一次抉择。又很庆幸自己是在这个时候才看的这部电影，小一些时，微薄的耐性一定无法让我... (展开)
3687 240 245回应 收起
彤彤 2008-06-03 18:05:24

## 历史上最刺眼的红

一边看电影一边记了五页的“笔记”，可是当真正要开始写的时候却很难下手。 要从沉重的心情中抽身出来，理性地看待这个问题，也许还需要一段时间。 还是一个讲述犹太人的故事，但是和上次看的《美丽人生》有所不同，色调上，角度上。 《美丽人生》是从犹太人的角度来讲的，... (展开)
2696 114 112回应 收起
Azulado 2006-09-05 21:47:08

## 二个世界

昨天晚上看了Schindler's List的上半部份, 先介绍一下影片, 再说一说Ralph在里面的表现.............. 　　 　　 我目前只看了上半部, 还是忍不住要说一下. 本片实际上有两个主角, 一个当然是Oskar Schindler,另一个就是Ralph扮演的,管理集中营的纳粹军官Amon Goeth.-------... (展开)
1146 143 184回应 收起
祥瑞御兔 2015-08-16 04:11:31

## 第三遍看重新发现的细节，想到多少记多少

1.影片在犹太人祭奠的开场后第一个场景是集中乡村犹太人并将其运送至城市的火车站。第一个出现的人物——携带便携桌椅、文牍表格和文具，对犹太人进行登记的德意志官吏。影片后来的段落中他们还多次出现，细细体会才发觉他们才象征着全片中最为恐怖的力量——一丝不苟地按规章... (展开)
475 32 47回应 收起
原鹰 2006-06-19 17:48:51

## 阿蒙的心中有个天使

昨天在蚝油的介绍下，来到圈内人的天堂里掏碟。本想把我热爱的夫夫的碟子都找出来的，可惜近来被严查，所以这个paradise也变得稀稀落落。最后找到一部和他挨上边的《辛德拉的名单》。这部片子早在几年前就已经看过了，当时我被主角的仁义和伟大感动得淅沥哗啦，但是还不认识Ra... (展开)
514 65 127回应 收起
斗室的碎玉 2005-12-06 11:58:40

## 感动于良知

对于和战争有关的电影，女生的兴趣一向都低于男生。几年在北京前买了这个电影的dvd, IT男看过之后推崇备至 ，而我却一直都没有完全看过，仅仅看过其中的一些片断。 当时印象比较深刻的是纳粹在Krakow大屠杀后继续“清洗”躲藏在房子角落、夹层、壁橱或钢琴中的犹太人，其间一... (展开)
247 52 89回应 收起
不吭声 2008-07-22 21:33:23

## 时代的恶之花

---略论二战电影中的纳粹军官 给人类带来无尽灾难的二战，留下了无数的悲情故事，呈现这些故事的电影精彩纷呈、经典辈出，在二战题材的电影里，有一类人总是能勾起人们滔天的愤怒，恨不得对其食肉寝皮，这种邪恶的存在就是那些无恶不作的纳粹军官们。作为纳粹德国的爪牙，这... (展开)
187 17 12回应 收起
郭大侠可爱多 2010-06-30 12:31:59

## 《辛德勒的名单》

影片《辛德勒名单》是导演斯蒂芬·斯皮尔伯格在1993年拍摄的一部轰动世界的鸿篇巨制，对二战期间德国纳粹屠杀600万犹太人惨剧的回顾，让人们重温50年前的恶梦。影片以悲观阴郁的基调和富于强烈戏剧张力的惊诧元素，透过主人公辛德勒的眼睛，重回二战时波兰的科拉科，... (展开)
319 6 12回应 收起
酒鬼一家小迷妹 2018-01-28 21:35:31

## 值得被永远铭记的辛德勒

这篇影评可能有剧透

这是我看过的一部印象深刻的影片。战争无疑带来的只有痛苦，身处战争时代的人更是苦不堪言。看到德国军官屠杀犹太人的场景，即使是躲在暗处也无法幸免，真的是草菅人命。这时候辛德勒的出现真的宛如救世主，为流离失所命悬一线的犹太人提供了所谓避难所，让他们在自己的工厂里... (展开)
67 1 7回应 收起

> 更多影评 2964篇

添加新讨论

## 讨论区 · · · · · ·

辛德勒逃亡离开嚎啕大哭有点过于煽情了 | 来自Jason | 15 回应 | 2022-11-24 21:00:01
这种电影属于艺术品吗 | 来自随遇而安 |  | 2022-11-24 11:04:37
个人感觉有两处不是很合常理的地方 | 来自岛主 |  | 2022-11-22 00:58:33
抛开影片看待今天的犹太人，犹太人值得同情吗？ | 来自果子哥哥 | 62 回应 | 2022-11-21 18:14:59
对不起，我接受不了 | 来自基尔邦硬 | 13 回应 | 2022-11-20 16:59:25

> 去这部影片的讨论区（全部536条）

## 关于《辛德勒的名单》的问题 · · · · · · ( 全部34个 )

- 德国人自己看到这种片子会怎么想呢？ 27人回答
- 一个问题，影片结尾那些在墓碑上放石头的人是真人还是演员？ 11人回答

> 全部34个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- 电影学院本科生必看100部 (志国)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)

## 谁在看这部电影 · · · · · ·

- Riko160
  刚刚 看过
- 原野的夏天
  刚刚 想看
- 💗
  3分钟前 想看

1793985人看过 / 584695人想看

订阅辛德勒的名单的评论:
feed: rss 2.0